The current version of the Autonomous Economic Agent framework is `0.2.2`. The framework is under rapid development with frequent breaking changes.

To check which version you have installed locally, run

```bash
aea --version
```